#include <iostream>
#include <fstream>
#include <iomanip>
#include <map>
#include <string>
#include <sstream>
#include <cctype>
#include <cerrno>

#ifdef GMP
#include <gmpxx.h>
#endif

using namespace std;

#include "parser/SimpleParser.hh"
#include "PseudoBooleanLinearizerCallback.hh"

int main(int argc, char *argv[])
{
  if (argc!=2)
  {
    cout << "usage: " << argv[0] << " <OPB file>" << endl
	 << "\ttranslate a non-linear pseudo-Boolean instance into a linear\n"
	 << "\tpseudoBoolean instance which is output to stdout." << endl;

    exit(1);
  }

  try
  {
    string instance=argv[1];

    PseudoBooleanLinearizerCallback<IntegerType> cb;

    ifstream in;

    SimpleParser<PseudoBooleanLinearizerCallback<IntegerType> > parser(cb);

    in.open(instance.c_str());

    // parse the file
    parser.setAutoLinearize(true);
    parser.setInput(in);
    parser.parse();
  }
  catch (exception &e)
  {
    cout.flush();
    cerr << "\n\tUnexpected exception :\n";
    cerr << "\t" << e.what() << endl;
    exit(1);
  }
}

